/*

ti pa
00.0 = void
01.3 = sky

24.3 25.3 26.3 27.3
2C.3 33.3 33.3 2F.3
34.3 33.3 33.3 37.3
3C.3 3D.3 EE.3 3F.3 = big ball

38.3 39.3 = big branch

2D.3 2E.3
35.3 36.3 = small ball

3A.3 3B.3 = small branch

61.0 = horizontal pipe
60.1 = pipe left edge
62.1 = pipe right edge

2B.2 = inside background
23.2 = inside shadow

68.0 {69.0} 6A.0
70.0 {71.0} 72.0 = pillar

83.0 = ladder

C4.1 = spike up

51.0 52.0 53.0 = wily ornament
10.0 = wily door



*/
static void BombmanAscii(Screen& s)
{
    for(unsigned y=0; y<16; ++y)
        for(unsigned x=0; x<16; ++x)
        {
            unsigned char c = s.outmap[y*16+x].tile;
            unsigned char p = s.outmap[y*16+x].palette;
            
            char ch = '?';
            /* Classify types.
             *
             *
             *
             */
            switch(c)
            {
                // sky:
                case 0x01: // sky
                case 0x24 ... 0x27:
                case 0x2C: case 0x33: case 0x2F:
                case 0x34: case 0x37:
                case 0x3C ... 0x3F: // big tree
                case 0x38 ... 0x39: // big branch
                case 0x2D ... 0x2E:
                case 0x35 ... 0x36: // small tree
                case 0x3A ... 0x3B: // small branch
                case 0x00: // void
                    ch = '.';
                    break;
                
                case 0x60 ... 0x62:
                case 0x68 ... 0x6A:
                case 0x70 ... 0x72:
                case 0x51 ... 0x53:
                    ch = '#';
                    break;
                case 0x23: case 0x2B:
                    ch = ' '; // inside
                    break;
                case 0x83:
                    ch = Ascii_Ladder;
                    break;
                case 0xC4:
                    ch = Ascii_Spike;
                    break;
                    
                case 0x10:
                    ch = Ascii_WilyDoor;
                    break;
                
                // There are no gutsblocks in Bombman level.
            }
            
            s.ascii[y*32+x] = ch;
            s.ascii[y*32+x+16] = ' ';
            //printf("%02X",c);      
        }
}

#define BombmanChar  DummyChar

static Level Bombman =
{
	2, // level number
	"Bombman",

	// screens:
	{
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"################"   "                "
		"....####........"   "                "
		"################"   "                "
		"....####........"   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "          j     "
		"........####...."   "                "
		"........####...."   "      j      j  "
		"....##########.."   "                "
		"....########...."   "   j           j"
		"################"   "                "
		"........########"   "                "
		"################"   "                "
		"........####...."   "                "
		"################"   "                "
		"........####...."   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"################"   "                "
		"....####........"   "                "
		"################"   "                "
		"....####........"   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"..##......##...."   "                "
		"..##......##...."   "                "
		"####....####...."   "                "
		"####......##...."   "                "
		"####..######..##"   "                "
		"..##..######...."   "                "
		"####......##..##"   "     B       B  "
		"..##......##...."   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"..##......##...."   "                "
		"..##......##...."   "                "
		"####....####...."   "                "
		"####......##...."   "                "
		"####..######..##"   "                "
		"..##..######...."   "                "
		"####......##..##"   "     B       B  "
		"..##......##...."   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		".............##."   "                "
		"....##...######."   "                "
		"....##.........."   "                "
		"..####.........."   "                "
		"....##.........."   "                "
		"################"   "          v     "
		"....###########."   "                "
		"################"   "                "
		"....###########."   "                "
		,Right},
		{
		"..............|#"   "                "
		"..............|#"   "                "
		"..............|#"   "                "
		"..............|#"   "                "
		".......#########"   "  ee            "
		"..##.........##."   "                "
		"..........######"   "                "
		"......#....#####"   "                "
		"............####"   "                "
		".............##."   "                "
		".....#.......###"   "            P   "
		"...........#####"   "                "
		"################"   "v     v         "
		".............##."   "                "
		"################"   "                "
		".............###"   "                "
		,Up},
		{
		"..|........#####"   "                "
		"..|.........####"   "                "
		"..|............#"   "                "
		"..|...........##"   "                "
		"..######|#.....#"   "                "
		"....##..|#.....#"   "      >         "
		"....##..|###...#"   "                "
		"....##..|###...."   "      ^         "
		"....##..|.####|#"   "                "
		"....##..|#####|."   "      >         "
		"....##..|....#|#"   "                "
		"....##..|....#|#"   "      ^     E   "
		"........######|#"   "                "
		"^^^^^^^^..##..|."   "                "
		"##############|#"   "                "
		"..........##..|#"   "                "
		,Up},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"..|#############"   "                "
		"..|#########...."   "                "
		"..|#############"   "                "
		"..|#########...."   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "G               "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"################"   "                "
		"....####........"   "                "
		"################"   "                "
		"....####........"   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"..##......##...."   "                "
		"..##......##...."   "         <      "
		"####....####...."   "        s       "
		"####......##...."   "                "
		"####..######..##"   "                "
		"..##..######...."   "                "
		"####......##..##"   "                "
		"..##......##...."   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"..##......##...."   "                "
		"..##......##...."   " <       <      "
		"####....####...."   "                "
		"####......##...."   "                "
		"####..######..##"   "                "
		"..##..######...."   "                "
		"####......##..##"   "                "
		"..##......##...."   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"..|#########...."   "                "
		"..|#########...."   "                "
		"..|##..........."   "                "
		"..|##..........."   "            f   "
		"..|##..#########"   "                "
		"..|##..#########"   "                "
		"..|##..........."   "                "
		"..|##..........."   "                "
		"################"   "                "
		"...#############"   "                "
		"#####.........##"   "                "
		"...##.........##"   "                "
		,Right},
		{
		"..............|#"   "                "
		"..............|#"   "                "
		"..............|#"   "                "
		"..............|#"   "                "
		".......#########"   "  f             "
		"..##.........##."   "                "
		"..........######"   "                "
		"......#....#####"   "                "
		"............####"   "                "
		".............##."   "                "
		".....#.......###"   "                "
		"...........#####"   "          f     "
		"################"   "                "
		".............##."   "                "
		"################"   "                "
		".............###"   "                "
		,Up},
		{
		"..|............."   "                "
		"..|............."   "                "
		"..|............."   "                "
		"..|............."   "                "
		"..|............."   "                "
		"..|..#...#...#|#"   "                "
		"..|...........|#"   "                "
		"..|...........|#"   "                "
		"..|...........|."   "               s"
		"..|...........|#"   "                "
		"..|...........|."   "                "
		"..|...........|#"   "                "
		"......########|#"   "                "
		"^^^^^^........|#"   "                "
		"##############|."   "                "
		"..............|."   "                "
		,Up},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"........#...#..."   "                "
		"................"   "               u"
		"................"   "                "
		".......#........"   "                "
		"................"   "                "
		"..|##..........."   "                "
		"..|##^^^^^^^^^^^"   "                "
		"..|#############"   "                "
		"..|#############"   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"################"   "                "
		"....####........"   "                "
		"################"   "                "
		"....####........"   "                "
		,Right},
		{
		"........##......"   "                "
		"........##......"   "                "
		".....##.##......"   "                "
		".....##.##......"   "                "
		"..|####........."   "             G  "
		"..|####........."   "                "
		"..|..##.##......"   "                "
		"..|####.##......"   "               U"
		"..|..##.########"   "                "
		"..|####.########"   "                "
		"..|####........."   "                "
		"..|####........."   "                "
		"################"   "                "
		".....##........."   "                "
		"################"   "                "
		".....##........."   "           u    "
		,Right},
		{
		"......##########"   "                "
		"......##########"   "                "
		"..........######"   "                "
		"......########.."   "                "
		"..........######"   "                "
		"......##########"   "                "
		"......##########"   "                "
		"......##########"   "                "
		"##############.."   "                "
		"##############.."   "                "
		"................"   "                "
		"................"   "                "
		"################"   "                "
		"..........######"   "                "
		"################"   "                "
		"..........####.."   "                "
		,Right},
		{
		".............###"   "                "
		".............###"   "                "
		".............###"   "                "
		".............###"   "                "
		".............###"   "                "
		".............###"   "                "
		"..............DD"   "              SS"
		"..............DD"   "              SS"
		"..............DD"   "             GSS"
		"..............DD"   "              SS"
		"..........######"   "                "
		"..........######"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"..........######"   "                "
		,Shutter},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"############...."   "                "
		"############...."   "                "
		"          ##...."   "X               "
		"          ##...."   "X               "
		"          ##...."   "X               "
		"          ##...."   "X               "
		"######  | ##...."   "                "
		"######  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		,Down},
		{
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "      h         "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "         h      "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "      h         "
		"....##  | ##...."   "                "
		"....##  | ##...."   "         h      "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		,Down},
		{
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "      h         "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "         h      "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "      h         "
		"....##  | ##...."   "                "
		"....##  | ##...."   "         h      "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		,Down},
		{
		"######    ######"   "      XXXX      "
		"######    ######"   "      XXXX      "
		"#              #"   "      XXXX      "
		"#              #"   "                "
		"#              #"   "                "
		"#              #"   "                "
		"#              #"   "                "
		"#              #"   "                "
		"#              #"   "                "
		"#              #"   "                "
		"#              #"   "                "
		"#              #"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		,End},
	},

	// palette
	{
		15, 32, 16, 17, 
		15, 32, 16, 33, 
		15, 41, 25,  7, 
		15, 39,  6, 33, 

		15, 44, 17, 15, 
		15, 32, 56, 15, 
		15, 48, 21, 15, 
		15, 48, 17, 15, 

		15, 32, 16, 17, 
		15, 32, 16, 33, 
		15, 32, 16,  0, 
		15, 39,  6, 33, 
	},

	// actives
	{
	},

	// enemies
	{
	},

	BombmanAscii, BombmanChar
};



