static void CutmanAscii(Screen& s)
{
    GenericAsciiMaker(s,
// Sky
-1,'.', 0x01,1, // cyan background
-1,'.', 0x00,0, // black background
// Background
-1,' ', 0x23,3, // window top
        0x24,3, // window bottom
-1,' ', 0x26,2, 0x25,2, // background, shadow
        0x2C,2, 0x2B,2, // inset decoration, shadowed
        0x34,2, 0x35,2, 0x3C,2, // exposed pipes (begin,repeat,end)
// Walls
-1,'#', 0x62,0, // step
-1,'#', 0x68,0, 0x69,0, // walls
-1,'#', 0x51,0, 0x52,0, 0x53,0, // Wily signature
// Wily door
-1,'D', 0x10,0,
// Gutsblock
-1,'G', 0x38,0, 0x39,0,
        0x3A,0, 0x3B,0,
// Ladder
-1,'|', 0x82,0,
// Spike
-1,'^', 0xC4,1, // sky bg
// Scissor machine
-1,'C', 0x20,2, 0x21,2, 0x2A,2, // top side
        0x3D,2, // left edge
        0x2D,2, // ladders
        0x2E,2, 0x2F,2, // pipes
        0x27,2, // right edge
        0x36,2, 0x37,2,
        0x3E,2, 0x3F,2, // scissor hole
-2);
}

static void CutmanChar(Screen& s)
{
    unsigned randseed = 0;
    for(unsigned y=0; y<16; ++y)
        for(unsigned x=0; x<16; ++x)
            randseed += s.ascii[y*32+x];
    std::srand(randseed);
    
    
    char decorations[16*16];
    for(unsigned y=0; y<16; ++y)
        for(unsigned x=0; x<16; ++x)
        {
            char c;
            switch(std::rand() % 6)
            {
                case 0: c = 1; break;
                case 1: c = 2; break;
                default: c = 0; break;
            }
            decorations[y*16+x] = c;
        }


    // Convert to tiles
    for(unsigned y=0; y<16; ++y)
        for(unsigned x=0; x<16; ++x)
        {
            unsigned char c   = 0;
            unsigned char pal = 0;
            
            /* Cutman palettes:
             *   
             * 0 = solid
             * 1 = blacks
             * 2 = blues
             * 3 = blue,gray
             */
            
            switch(s.ascii[y*32+x])
            {
                case '.':
                    c   = 0x01; // background
                    pal = 0x01;
                    break;
                case ' ':
                    if(y > 0 &&
                        (s.ascii[(y-1)*32+x] != '.'
                      && s.ascii[(y-1)*32+x] != ' ')
                      )
                        c = 0x25; // shadow
                    else
                    {
                        switch(decorations[y*16+x])
                        {
                            case 1:
                                c = 0x2C; // inset decoration
                                break;
                            case 2:
                                c = 0x35;
                                if(x<16
                                && decorations[y*16+x+1]==2
                                && (x==0 || decorations[y*16+x-1]!=2))
                                    c = 0x34; // beginning

                                if(x>0  && s.ascii[y*32+x-1] == ' '
                                && x<15 && s.ascii[y*32+x+1] == ' ')
                                {
                                    break;
                                }
                                // passthru
                            case 0:
                                c = 0x26; // no decoration
                        }
                    }
                    pal = 0x02;
                    break;
                case '#':
                    if(y > 0 &&
                        (s.ascii[(y-1)*32+x] != '#')
                      )
                        c = 0x62; // step
                    else
                        c = 0x68 + ((x+y) & 1);
                    pal = 0x00;
                    break;
                case Ascii_Ladder:
                    c   = 0x82; // ladder
                    pal = 0x00;
                    break;
                case Ascii_Spike:
                    c   = 0xC4; // spike
                    if(y>0 && s.ascii[(y-1)*32+x] == ' ')
                        pal = 0x03;
                    else
                        pal = 0x01;
                    break;
                case Ascii_Guts:
                    c   = 0x38 + (x&1) + (y&1)*2; // gutsblock
                    pal = 0x00;
                    break;
                case Ascii_WilyDoor:
                    c   = 0x10;
                    pal = 0x00;
                    break;
                default:
                    printf("? '%c'\n", s.ascii[y*32+x]);
            }
            
            s.outmap[y*16+x].tile    = c;
            s.outmap[y*16+x].palette = pal;
        }
}


static Level Cutman =
{
	0, // level number
	"Cutman",

	// screens:
	{
		{
		"...............#"   "                "
		"...............#"   "                "
		"...............#"   "                "
		"...............#"   "                "
		"........GG.....#"   "                "
		"........GG.....#"   "                "
		"#####|####|#..##"   "                "
		"     |  ..|....#"   "                "
		"     |  ..GG...#"   "                "
		"     |  ..GG...#"   "                "
		"     |  ..GG...#"   "                "
		"     |  ..GG...#"   "                "
		"  ##############"   "                "
		"  ##############"   "                "
		"  ##############"   "                "
		"  ##############"   "                "
		,Down},

		{
		"........########"   "                "
		"........####...."   "                "
		"........|  #...."   "                "
		"###.....|  #...."   "                "
		"#  .....|  #...."   "                "
		"#  .....|  #...."   "  P P     M     "
		"############..##"   "                "
		"     |  ......  "   "                "
		"     |  ......  "   "                "
		"     |  ......  "   "                "
		"     |  GGGG..  "   "             t  "
		"     |  GGGG..  "   "                "
		"  ##############"   "                "
		"  ##############"   "                "
		"  ##############"   "                "
		"  ##############"   "                "
		,Down},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "   y            "
		"................"   "        y       "
		"........GG......"   "                "
		". #.....GG......"   "                "
		"......####......"   "       y        "
		"......####..##.."   "                "
		"....######..##.."   "                "
		"....######..####"   "                "
		"  ########..####"   "                "
		"  ########..####"   "                "
		"  ########..####"   "                "
		"  ########..####"   "                "
		,Down},
		{
		"........    #|##"   "                "
		"........    #|##"   "                "
		"........     |##"   "                "
		"........     |##"   "                "
		"....#|#  #######"   "   <            "
		"....#|#  #######"   "                "
		"....#|      ####"   "                "
		". #.#|      ####"   "           <    "
		"....#|      ####"   "                "
		"....#|###   ####"   "                "
		"....       #####"   "                "
		"....       #####"   "                "
		"  ##############"   "                "
		"  ##############"   "                "
		"  ##############"   "                "
		"  ##############"   "                "
		,Down},
		{
		".............|##"   "                "
		".............|##"   "                "
		".............|##"   "                "
		"..........######"   "         {      "
		"..........######"   "                "
		"........########"   "       <        "
		"........########"   "                "
		". #...##########"   "                "
		"...#..##########"   "                "
		"...#....      ##"   "             <  "
		"........      ##"   "                "
		"........      ##"   "                "
		"  #.....      ##"   "                "
		"  ########  #|##"   "                "
		"  ########  #|##"   "                "
		"  ########  #|##"   "                "
		,Down},
		{
		"..........   |##"   "                "
		"..........   |##"   "                "
		"..........   |##"   "                "
		"..........  ####"   "           {    "
		"..........  ####"   "                "
		"...#......######"   "                "
		"...#......######"   "                "
		". #.....#|######"   "       <        "
		"........#|######"   "                "
		".........|    ##"   "                "
		".........|    ##"   "                "
		"...#.....|    ##"   "    >           "
		"  ##.....|    ##"   "                "
		"  ###...#####|##"   "                "
		"  ###...#####|##"   "                "
		"  ###...#####|##"   "                "
		,Down},
		{
		"...|  ##########"   "                "
		"...|   #########"   "                "
		"...|      ######"   "         <      "
		"...|       #####"   "                "
		"...|        ####"   "                "
		"...#####    ####"   "           {    "
		"....        ####"   "                "
		". #.        ####"   "                "
		"...#|###########"   "                "
		"....|       ####"   "                "
		"....|         ##"   "                "
		"....|         ##"   "                "
		"  #.|         ##"   "                "
		"  #####  ####|##"   "       >        "
		"  #####  ####|##"   "                "
		"  #####  ####|##"   "                "
		,Down},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		". #............."   "                "
		"......??????...."   "                "
		"......??????...."   "                "
		"......??????...."   "                "
		"......??????...."   "         r      "
		"  #...??????####"   "                "
		"  #|############"   "                "
		"  #|############"   "                "
		"  #|############"   "                "
		,Down},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"........GG......"   "                "
		". #.....GG......"   "       j        "
		"......####......"   "                "
		"......####..##.."   "     j          "
		"....######..##.."   "                "
		"....######..####"   "   j            "
		"  ########..####"   "                "
		"  ########..####"   "                "
		"  ########..####"   "                "
		"  ########..####"   "                "
		,Down},
		{
		"........    #|##"   "                "
		"........    #|##"   "                "
		"........     |##"   "                "
		"........     |##"   "                "
		"....#|#  #######"   "                "
		"....#|#  #######"   "                "
		"....#|      ####"   "      c         "
		". #.#|      ####"   "                "
		"....#|      ####"   "           h    "
		"....#|###   ####"   "                "
		"....       #####"   "    c           "
		"....       #####"   "                "
		"  ##############"   "                "
		"  ##############"   "                "
		"  ##############"   "                "
		"  ##############"   "                "
		,Down},
		{
		"..........   |##"   "                "
		"..........   |##"   "                "
		"..........   |##"   "                "
		"..........   |##"   "                "
		"...#......  ####"   "    h           "
		"..........    ##"   "                "
		"........##    ##"   "       h        "
		". ##|#..    ####"   "                "
		"....|...      ##"   "     c       h  "
		"....|...      ##"   "                "
		"....|.GG      ##"   "                "
		"....|.GG      ##"   "                "
		"  ###########|##"   "                "
		"  ###########|##"   "                "
		"  ###########|##"   "                "
		"  ###########|##"   "                "
		,Down},
		{
		"........      ##"   "                "
		"........      ##"   "                "
		"........      ##"   "                "
		"........      ##"   "                "
		"........      ##"   "             h  "
		"........      ##"   "                "
		"........    ####"   "           h    "
		". #.....    ####"   "                "
		"...G....  ######"   "                "
		"...G....  ######"   "                "
		"...###..########"   "       h        "
		"...###..      ##"   "        c       "
		"  ####..      ##"   "                "
		"  ###########|##"   "                "
		"  ###########|##"   "                "
		"  ###########|##"   "                "
		,Down},
		{
		"...|############"   "                "
		"...|############"   "                "
		"...|....      ##"   "            c   "
		"...|....      ##"   "                "
		"........      ##"   "  h             "
		"........      ##"   "                "
		"...#|...    ####"   "                "
		". #.|...    ####"   "   c            "
		"....|.GG    ####"   "        h       "
		"....|.GG    ####"   "                "
		"....############"   "   h            "
		"....############"   "                "
		"  #.############"   "                "
		"  ##############"   "                "
		"  ##############"   "                "
		"  ##############"   "                "
		,Down},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		". #............."   "                "
		"......??????...."   "                "
		"......??????...."   "                "
		"......??????...."   "                "
		"......??????...."   "         r      "
		"  #...??????..##"   "                "
		"  #|############"   "                "
		"  #|############"   "                "
		"  #|############"   "                "
		,Down},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"......##########"   "                "
		". #...##########"   "                "
		"...#############"   "                "
		"...#############"   "                "
		"...#############"   "                "
		"...#############"   "                "
		"  ##############"   "                "
		"  ##############"   "                "
		"  ##############"   "                "
		"  ##############"   "                "
		,Down},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "      y         "
		"................"   "          y     "
		"................"   "                "
		". #............."   "                "
		"...#########...."   "         y      "
		"...#########...."   "                "
		"................"   "                "
		"................"   "  E             "
		"  ##########|#.."   "                "
		"  ##########|#.."   "                "
		"  ##########|#.."   "                "
		"  ##########|#.."   "                "
		,Down},
		{
		"...###......|..."   "                "
		"...##.......|..."   "                "
		"...##.......|..."   "                "
		"...###|#######.."   "                "
		"...###|#######.."   "                "
		"...# ..........."   "                "
		"...# ..........."   "                "
		". #  ..........."   "                "
		"...  ..........."   "               u"
		"...  .##..##...."   "                "
		"...  ..........."   "                "
		"...  ..........."   "                "
		"  #  ..........."   "                "
		"  ####|#........"   "                "
		"  ####|#........"   "                "
		"  ####|#........"   "                "
		,Down},
		{
		"...###|#........"   "                "
		"...###|#........"   "                "
		"...###  ........"   "                "
		"...###  .....^^."   "                "
		"...#####.....##."   "                "
		"...#####........"   "                "
		"...#  .........."   "                "
		". ##  .........."   "                "
		"...   .........."   "               u"
		"...   .##....##."   "                "
		"...   .........."   "                "
		"...   .........."   "                "
		"  #   .........."   "                "
		"  ######^^^^^^^^"   "                "
		"  ##############"   "                "
		"  ##############"   "                "
		,Down},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		". #............."   "                "
		"...GGG.........."   "                "
		"...GGG.........."   "                "
		"...#GGGG........"   "              t "
		"...#GGGG........"   "                "
		"  ##############"   "                "
		"  ##############"   "                "
		"  ##############"   "                "
		"  ##############"   "                "
		,Down},

		{
		".............###"   "                "
		".............###"   "                "
		".............###"   "                "
		".............###"   "                "
		".............###"   "                "
		".............###"   "                "
		"..............DD"   "              SS"
		". #...........DD"   "              SS"
		"..............DD"   "              SS"
		"..............DD"   "              SS"
		"..........######"   "                "
		"..........######"   "                "
		"################"   "                "
		"  ##############"   "                "
		"  ##############"   "                "
		"  ##############"   "                "
		,Shutter},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"################"   "                "
		"################"   "                "
		"                "   "X               "
		"                "   "X               "
		"                "   "X               "
		"                "   "X               "
		"################"   "             v  "
		"################"   "                "
		".##............."   "                "
		"..#########....."   "                "
		"..##############"   "                "
		"................"   "                "
		,Right},
/*		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"################"   "                "
		"################"   "                "
		"                "   "            .   "
		"                "   "                "
		"                "   "                "
		"                "   "                "
		"################"   "                "
		"################"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		,Right},
*/		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"################"   "                "
		"################"   "                "
		"               D"   "               S"
		"               D"   "               S"
		"                "   "                "
		"                "   "                "
		"################"   "     v          "
		"################"   "                "
		"................"   "                "
		"................"   "                "
		"################"   "                "
		"................"   "                "
		,Right},
		{
		"################"   "                "
		"################"   "                "
		"#              #"   "                "
		"#              #"   "                "
		"#              #"   "                "
		"#              #"   "                "
		"               #"   "X               "
		"               #"   "X               "
		"               #"   "                "
		"               #"   "                "
		"##GGGG         #"   "                "
		"##GGGG         #"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		,End},
	},

	// palette
	{
		15, 48, 43,  6, 
		15, 48, 43, 44, 
		15, 32, 16,  0, 
		15, 32, 16, 44, 

		15, 44, 17, 15, 
		15, 32, 56, 15, 
		15, 48, 17, 15, 
		15, 48, 21, 15, 

		15, 48, 43,  6, 
		15, 48, 43, 44, 
		15, 48, 32, 16, 
		15, 32, 16, 44, 
	},

	// actives
	{
	},

	// enemies
	{
	},

	CutmanAscii, CutmanChar
};
