#ifndef bqtRockEditDEFsHH
#define bqtRockEditDEFsHH

enum
{
    Up      = 2,
    Down    = 4,
    Shutter = 8,
    Right   = 1,
    End     = 1,
    Last    = 0
};

// Routine $C39C: load the page of the level

// In each page, these settings are constant:
static const unsigned Addr_Blocks   = 0x0000; // Max blocks: 192 (shared)
static const unsigned Addr_BlockPals= 0x0300; // Max blocks: 192 (shared)
static const unsigned Addr_Rooms    = 0x03C0; // Max rooms: 33   (shared)
static const unsigned Addr_Order    = 0x0C00; // Max screens: 48 (shared)
static const unsigned Addr_Pointers = 0x0C30; // Max rooms: 32.  (shared)
static const unsigned Addr_Layout   = 0x0C70; // Max screens: 48. (shared)
static const unsigned Addr_Palette1 = 0x0CA0;
static const unsigned Addr_Palette2 = 0x0CD0;
static const unsigned Addr_Tiles1   = 0x0D00; // Map1 ?table (number, followed by 2 bytes each)
static const unsigned Addr_Tiles2   = 0x0D20; // Map2 ?table
static const unsigned Addr_Tiles3a  = 0x0D40; // Something common to both
static const unsigned Addr_Tiles3b  = 0x0D80; // Something common to both
static const unsigned Addr_Actives1 = 0x0E00;
static const unsigned Addr_Actives2 = 0x0EA0;
static const unsigned Addr_ActivesEnd=0x0F00; // begin gfx sprites
static const unsigned Addr_Tiles3c   =0x0F80; // Something common to both, also F70.
  // E00: 1 byte: number of objects (map1) Including terminator
  //      6 bytes per object. Terminator = 2nd byte is $FF
  //      Max objects: 29
  //  0: type
  //       2=gutsblock, 3=door_right, 1=door_left, 0=appearing block
  //  1: screen #
  //  2: x1 (in)
  //  3: y1 (in)
  //  4: x2 (out)
  //  5: y2 (out)
  // EB0: 1 byte: number of objects (map2) Including terminator
  //      6 bytes per object. Terminator = 2nd byte is $FF
  //      Max objects: 13
  // F00: gfx

static const unsigned Addr_EnemyPointers = 0x1A452; //C,I,B,F,E,G,1,2,3,4,? point to A468+.
static /***/ unsigned Addr_EnemyData     = 0x1A468; // room for 419 enemies (total).
static const unsigned Addr_EnemyEnd      = 0x1AB00;

/* Address of the 10-byte table which lists the offsets of
 * each level's order table, relative to the page's Addr_Order.
 */
static const unsigned Addr_OrderOffsetTable = 0x1C2EB;

/* Address of the 10-byte table which lists the room numbers
 * of each level where the boss appears.
 */
static const unsigned Addr_BossOffsetTable = 0x1CE49;

  // Enemies is list of 4-byte records, terminated by byte $FF.
  //  0: screen #
  //  1: x (center)
  //  2: y (center)
  //  3: type

/* Common ascii characters in all levels */
static const char Ascii_Guts     = 'G';
static const char Ascii_Spike    = '^';
static const char Ascii_Ladder   = '|';
static const char Ascii_WilyDoor = 'D';

static const char Ascii_ObjShutterIn  = 'X'; // input shutter
static const char Ascii_ObjShutterOut = 'S'; // output shutter
// pneumatic  blocks are represented by hex characters 0..9
static const char Ascii_ObjFire    = 'I'; // flying fire

// reserved: X, S, I, 0-9
static const struct ObjectDesc
{
    char ascii;
    unsigned x,y;
} AsciiObjects[] =
{
  //  0
  { 'y', 0x0,0xC }, // bunby heri - the annoying thing in Cutman level beginning
  { 'm', 0x0,0x8 }, // metto
  { 'j', 0x8,0x8 }, // red jumping junk
  { 'f', 0x8,0xC }, // floor trap
  //  4
  { 'c', 0x8,0x8 }, // vertically moving eyecube
  { 'v', 0x8,0x0 }, // spread cannon in floor
  { 0 },   // SPECIAL, SEE BELOW
  { 'i', 0x0,0x0 }, // sinewave flying penguin
  //  8
  { 's', 0xF,0x0 }, // sinewave flying bomb
  { 't', 0x0,0xC }, // jumping telephone post
  { 'u', 0x8,0x0 }, // hamburger
  { '<', 0x8,0x8 }, // singleshot cannon pointing left (timing 1)
  //  C
  { '-', 0x0,0x8 }, // elec arc
  { 'B', 0x8,0x0 }, // periodical bombing (y = 0xE0)
  { 0 },   // SPECIAL, SEE BELOW
  { 'I', 0x8,0x0 }, // flying fire, take two!
  // 10
  { 0 },   // SPECIAL, SEE BELOW
  { 0 },
  { 'G', 0x0,0x4 }, // green guardian (Xl=0, Yl=4)
  { 'L', 0x0,0xC }, // shooting lift
  // 14
  { 'R', 0x0,0x4 }, // robots that may lose their head
  { 'a', 0x0,0x4 }, // axe throwing robot in Gutsman
  { '.', 0x8,0x0 }, // spread cannon pointing down
  { '>', 0x8,0x8 }, // singleshot cannon pointing right
  // 18
  { ']', 0x4,0x6 }, // fire torch to the right (Fireman)
  { '', 0x0,0x7 }, // electricity decoration 1 (Elecman level only)
  { 0 },
  { 0 },
  // 1C
  { 'r', 0x0,0x4 }, // scissor machine
  { 0 },
  { 0 },
  { 0 },
  // 20
  { 0 },
  { 'h', 0x8,0x8 }, // horizontally moving eyecube
  { '{', 0x8,0x8 }, // singleshot cannon pointing left (timing 2)
  { '^', 0x8,0x8 }, // spread cannon pointing up
  // 24
  { '=', 0x0,0x8 }, // elec arc, different timing
  { '', 0x0,0x7 }, // electricity decoration 2 (Elecman level only)
  { 0 },
  { 0 },
  // 28
  { 0 },
  { 0 },
  { 0 },
  { 0 },
  // 2C
  { 0 },   // SPECIAL, SEE BELOW
  { 0 },
  { 0 },
  { 0 },   // SPECIAL, SEE BELOW
  // 30
  { 0 },   // SPECIAL, SEE BELOW
  { 'd', 0x0,0x0 }, // periodically three fire devils from lava to sky
  { 0 },   // SPECIAL, SEE BELOW
  { 0 },
  // 34
  { 0 },
  { 0 },
  { 0 },
  { 0 },
  // 38
  { 0 },
  { 0 },
  { 0 },   // wily3 boss
  { 'T', 0x4,0xC }, // teleport when a "boss" killed, activate enemy if not dead.
  // 3C
  { 'o', 0x8,0x9 }, // score ball
  { 'p', 0x8,0xC }, // small weapon
  { 'e', 0x8,0x9 }, // small energy
  { 'P', 0x8,0x8 }, // big weapon
  // 40 
  { 'E', 0x8,0x8 }, // big energy
  { 'U', 0x8,0x8 }, // 1up
  { 'M', 0x8,0x8 }, // magnet beam
  { 'O', 0x8,0x0 }, // teleport immediately (invisible)
  // 44
  { '*', 0x8,0x8 }, // end level
  { 'W', 0x8,0x8 }, // all weapons full
  { 0 },
  { 0 },
  // 48
  { 0 },
  { '', 0x8,0x8 }, // random powerup (enemy destruction)
};

/*
     Controllers:
     
     0x06 functions:
             10,FF = this room has "watchers" (The flying beamers in Elecman and Wily4)
     0x0E functions:
             D0,04 = falling fire (Fireman level)
             B0,FF = zigzag fire (Fireman level)
     0x10 functions:
             E0,80 = activate buzzblocks (Iceman) - used twice
             10,80 = activate buzzblocks (Elecman)
     0x2C functions:
             10,FF = unknown (Wily4, screen 2)
     0x2F functions:
             80,80 = super scrolling start (Wily3)
             FC,80 = unknown (Gutsman, screen 1)
             58,80 = unknown (Gutsman, screen 4)
     0x30 functions:
             80,80 = super scrolling stop (Wily3)
             F8,80 = launch lift (Gutsman, screen 0)
             80,FF = stop lift (Gutsman, screen 0)
             60,80 = unknown (Gutsman, screen 5)
     0x32 functions:
             80,E0 = lava activator (Fireman)
     0xFF functions:
             E0,0C = increase pace (wily3)
             01,08 = unknown (Gutsman, screen 5)
             40,0A = unknown (Gutsman, screen 5)
             10,04 = unknown (Gutsman, screen 6)
             50,06 = unknown (Gutsman, screen 6)
             80,02 = water start (Iceman)
             00,00 = water end   (Iceman)
 */


// A level may contain 48 rooms, but when two levels are paired, the total amount must <= 48.
static const unsigned MaxRooms   = 48;
// There is room for 13 actives at max per level.
static const unsigned MaxActives = 32;
// THere is room for 419 enemies at max per level.
static const unsigned MaxEnemies = 256;

#endif
